@@ -14,9 +14,9 @@ use strict;
 use warnings;
 use Carp;
 
-our $VERSION = '3.98';    # VERSION
+our $VERSION = '3.99';    # VERSION
 my @OPTIONS_ATTRIBUTES
-    = qw/format short repeatable negativable autosplit doc order json/;
+    = qw/format short repeatable negativable autosplit doc long_doc order json/;
 
 sub import {
     my ( undef, @import ) = @_;
@@ -26,6 +26,11 @@ sub import {
         skip_options          => [],
         prefer_commandline    => 0,
         with_config_from_file => 0,
+
+        #long description (manual)
+        description => undef,
+        authors     => [],
+        synopsis    => undef,
         @import
     };
 
@@ -114,7 +119,7 @@ sub import {
     };
 
     my @banish_keywords
-        = qw/help option new_with_options parse_options options_usage _options_data _options_config/;
+        = qw/help man option new_with_options parse_options options_usage _options_data _options_config/;
     if ( $options_config->{with_config_from_file} ) {
         push @banish_keywords, qw/config_files config_prefix config_dirs/;
     }
@@ -194,7 +199,7 @@ MooX::Options - create a command line tools with your Object (Mo / Moo / Moose)
 
 =head1 VERSION
 
-version 3.98
+version 3.99
 
 =head1 DESCRIPTION
 
@@ -585,13 +590,46 @@ If you have a subcommand "sub1", and another subcommand "sub2" of "sub1", this :
 
   myTools sub1 sub2 -h
 
-display an usage message :
+display an usage message from myTools :
 
-  USAGE: myTools sub1 sub2 [-h] ...
+  USAGE: myTools [-h] ...
+  ...
+  SUB COMMANDS AVAILABLE: sub1
 
-=head1 no more Mouse support
+display an usage message from myTools sub1:
 
-If you are using Mouse, I'm sorry to say than the rewrite of this module has make it just incompatible. Mouse is not design to by compatible with anything else than Mouse itself. I could just suggest to use Moo instead, which is a great and compatible replacement.
+  USAGE: myTools sub1 [-h] ...
+  ...
+  SUB COMMANDS AVAILABLE: sub2
+
+=head1 Man support
+
+The option "--man" is now avaible. And you can do more than only with "--help" option.
+
+The import support those options :
+
+=over
+
+=item description
+
+The description of your tools.
+
+=item authors
+
+The list of authors of your tools. You can use ever a string or an arrayref :
+
+  use MooX::Options authors => 'Celogeek <me@celogeek.com>'
+
+  use MooX::Options authors => ['Celogeek <me@celogeek.com', 'Jens Rehsack']
+
+=item synopsis
+
+  you can define a full example in pod format. This will be placed in the synopsis section
+
+=back
+
+The "option" key also support "long_doc" which will replace the default "doc" for the "--man".
+Use it for a more explicit help message.
 
 =head1 More examples
 
@@ -607,7 +645,7 @@ L<http://perltalks.celogeek.com/slides/2012/08/moox-options-slide3d.html>
 
 =item Torsten Raudssus (Getty) : to use it a lot in L<DuckDuckGo|http://duckduckgo.com> (go to see L<MooX> module also)
 
-=item Jens Rehsack (REHSACK) : to purpose the with_config_from_file idea for PKGSRC.
+=item Jens Rehsack (REHSACK) : to purpose the with_config_from_file idea for PKGSRC, and support of MooX::Cmd.
 
 =back
 
