@@ -9,7 +9,10 @@
 package t::lib::MooXCmdTest;
 use Moo;
 use MooX::Cmd;
-use MooX::Options;
+use MooX::Options
+    authors     => 'Celogeek <me@celogeek.com>',
+    description => 'This is a test sub command',
+    synopsis    => 'This is a test synopsis';
 
 sub execute {
     die "need a sub command !";
